@@ -5,6 +5,9 @@
 
 import logging
 import re
+from datetime import datetime, timedelta
+
+from mvt.android.parsers import parse_getprop
 
 from .base import AndroidExtraction
 
@@ -24,22 +27,17 @@ class Getprop(AndroidExtraction):
 
     def run(self):
         self._adb_connect()
-
-        rxp = re.compile(r"\[(.+?)\]: \[(.+?)\]")
-        out = self._adb_command("getprop")
-        for line in out.splitlines():
-            line = line.strip()
-            if line == "":
-                continue
-
-            matches = re.findall(rxp, line)
-            if not matches or len(matches[0]) != 2:
-                continue
-
-            key = matches[0][0]
-            value = matches[0][1]
-            self.results[key] = value
-
+        output = self._adb_command("getprop")
         self._adb_disconnect()
 
+        self.results = parse_getprop(output)
+
+        # Alert if phone is outdated.
+        security_patch = self.results.get("ro.build.version.security_patch", "")
+        if security_patch:
+            patch_date = datetime.strptime(security_patch, "%Y-%m-%d")
+            if (datetime.now() - patch_date) > timedelta(days=6*30):
+                self.log.warning("This phone has not received security updates for more than "
+                                 "six months (last update: %s)", security_patch)
+
         self.log.info("Extracted %d Android system properties", len(self.results))
